@@ -5,7 +5,7 @@
 #include "kmx_base.h"
 
 namespace km {
-namespace kbp {
+namespace core {
 namespace kmx {
 
 class KMX_Environment {
@@ -15,8 +15,8 @@ private:
   std::u16string _platform;
   void InitOption(
     std::vector<option> & default_env,
-    km_kbp_cp const * key,
-    km_kbp_cp const * default_value);
+    km_core_cp const * key,
+    km_core_cp const * default_value);
 public:
   KMX_Environment();
   void Set(std::u16string const & key, std::u16string const & value);
@@ -30,5 +30,5 @@ public:
 };
 
 } // namespace kmx
-} // namespace kbp
+} // namespace core
 } // namespace km
