@@ -4,8 +4,8 @@
  * Keyman Core - KMX Extended String unit tests
  */
 
-#ifndef KMN_KBP
-#define KMN_KBP
+#ifndef KM_CORE_LIBRARY
+#define KM_CORE_LIBRARY
 #endif
 #ifndef USE_CHAR16_T
 #define USE_CHAR16_T
@@ -19,9 +19,9 @@
 #include <string>
 #include "../../../src/kmx/kmx_xstring.h"
 #include <kmx_file.h>
-#include "../test_assert.h"
+#include <test_assert.h>
 
-using namespace km::kbp::kmx;
+using namespace km::core::kmx;
 using namespace std;
 
 #define U_1F609_WINKING_FACE u"\U0001F609"
@@ -1236,6 +1236,178 @@ test_xstrlen_ignoreifopt() {
   assert_equal(xstrlen_ignoreifopt((PKMX_WCHAR) U_1F609_WINKING_FACE u"a"), 2);
 }
 
+void
+test_utf32() {
+  std::cout << "== " << __FUNCTION__ << std::endl;
+  const KMX_DWORD u295 =     0x0127; // ħ
+
+  assert(Uni_IsBMP(u295));
+
+  const char16_t hmaqtugha = Uni_UTF32BMPToUTF16(u295);
+  assert(hmaqtugha == 0x0127);
+
+  char16_single c0;
+  int l0 = Utf32CharToUtf16(u295, c0);
+  assert(l0 == 1);
+  assert(c0.ch[0] == 0x0127);
+  assert(c0.ch[1] == 0);
+  std::u16string s0 = std::u16string(c0.ch, l0);
+  assert(s0 == std::u16string(u"ħ"));
+  assert_equal(s0.at(0), 0x0127);
+
+  const KMX_DWORD scat = 0x0001F640; // 🙀
+  assert(!Uni_IsBMP(scat));
+  char16_single c1;
+  int l1 = Utf32CharToUtf16(scat, c1);
+  assert(l1 == 2);
+  assert_equal(c1.ch[0], 0xD83D);
+  assert_equal(c1.ch[1], 0xDE40);
+  assert_equal(c1.ch[2], 0);
+  std::u16string s1 = std::u16string(c1.ch, l1);
+  assert_equal(s1.at(0), 0xD83D);
+  assert_equal(s1.at(1), 0xDE40);
+  assert(s1 == std::u16string(u"🙀"));
+}
+
+void
+test_u16string_to_u32string() {
+  std::cout << "== " << __FUNCTION__ << std::endl;
+  // normal cases
+  {
+    const std::u32string str = u16string_to_u32string(u"");
+    assert_equal(str.length(), 0);
+  }
+  {
+    const std::u32string str = u16string_to_u32string(u"e");
+    assert_equal(str.length(), 1);
+    assert_equal(str.at(0), 0x0065);
+  }
+  {
+    const std::u32string str = u16string_to_u32string(u"🙀");
+    assert_equal(str.length(), 1);
+    assert_equal(str.at(0), 0x0001F640);
+  }
+  {
+    const std::u32string str = u16string_to_u32string(u"Ω🙀");
+    assert_equal(str.length(), 2);
+    assert_equal(str.at(0), u'Ω');
+    assert_equal(str.at(1), 0x0001F640);
+  }
+
+  // error cases
+  {
+    std::u16string half_cat;
+    half_cat.push_back(0xD83D);  // mismatched lead surrogate
+    const std::u32string str = u16string_to_u32string(half_cat);
+    assert_equal(str.length(), 1);
+    assert_equal(str.at(0), 0xFFFD);
+  }
+  {
+    std::u16string half_cat;
+    half_cat.push_back(0xD83D);  // mismatched lead surrogate
+    half_cat.push_back(u'Ω');    // with following text
+    const std::u32string str = u16string_to_u32string(half_cat);
+    assert_equal(str.length(), 2);
+    assert_equal(str.at(0), 0xFFFD);
+    assert_equal(str.at(1), u'Ω');
+  }
+  {
+    std::u16string half_cat;
+    half_cat.push_back(0xDE40);  // mismatched trail surrogate
+    const std::u32string str = u16string_to_u32string(half_cat);
+    assert_equal(str.length(), 1);
+    assert_equal(str.at(0), 0xFFFD);
+  }
+  {
+      std::u16string no_cat;
+      no_cat.push_back(0xDE40);
+      no_cat.push_back(0xD83D);
+      const std::u32string str = u16string_to_u32string(no_cat);
+      assert_equal(str.length(), 2);
+      assert_equal(str.at(0), 0xFFFD);
+      assert_equal(str.at(1), 0xFFFD);
+  }
+}
+
+
+void
+test_u32string_to_u16string() {
+  std::cout << "== " << __FUNCTION__ << std::endl;
+  // normal cases
+  {
+    const auto str = u32string_to_u16string(U"");
+    assert_equal(str.length(), 0);
+  }
+  {
+    const auto str = u32string_to_u16string(U"e");
+    assert_equal(str.length(), 1);
+    assert_equal(str.at(0), 0x0065);
+  }
+  {
+    const auto str = u32string_to_u16string(U"🙀");
+    assert_equal(str.length(), 2);
+    assert_equal(str.at(0), 0xD83D);
+    assert_equal(str.at(1), 0xDE40);
+  }
+  {
+    const auto str = u32string_to_u16string(U"Ω🙀");
+    assert_equal(str.length(), 3);
+    assert_equal(str.at(0), u'Ω');
+    assert_equal(str.at(1), 0xD83D);
+    assert_equal(str.at(2), 0xDE40);
+  }
+}
+
+void test_is_valid() {
+  std::cout << "== " << __FUNCTION__ << std::endl;
+  // valid
+  assert_equal(Uni_IsValid(0x0000), true);
+  assert_equal(Uni_IsValid(0x0127), true);
+  assert_equal(Uni_IsValid(U'🙀'), true);
+
+  // invalid
+  assert_equal(Uni_IsValid(0xDECAFBAD), false); // out of range
+  assert_equal(Uni_IsValid(0x566D4128), false);
+  assert_equal(Uni_IsValid(0xFFFF), false); // nonchar
+  assert_equal(Uni_IsValid(0xFFFE), false); // nonchar
+  assert_equal(Uni_IsValid(0x10FFFF), false); // nonchar
+  assert_equal(Uni_IsValid(0x10FFFE), false); // nonchar
+  assert_equal(Uni_IsValid(0x01FFFF), false); // nonchar
+  assert_equal(Uni_IsValid(0x01FFFE), false); // nonchar
+  assert_equal(Uni_IsValid(0x02FFFF), false); // nonchar
+  assert_equal(Uni_IsValid(0x02FFFE), false); // nonchar
+  assert_equal(Uni_IsValid(0xFDD1), false); // nonchar
+  assert_equal(Uni_IsValid(0xFDD0), false); // nonchar
+
+
+ // positive range test
+  assert_equal(Uni_IsValid(0x100000, 0x10FFFD), true);
+  assert_equal(Uni_IsValid(0x10, 0x20), true);
+  assert_equal(Uni_IsValid(0x100000, 0x10FFFD), true);
+
+  // all valid ranges in BMP
+  assert_equal(Uni_IsValid(0x0000, 0xD7FF), true);
+  assert_equal(Uni_IsValid(0xD800, 0xDFFF), false);
+  assert_equal(Uni_IsValid(0xE000, 0xFDCF), true);
+  assert_equal(Uni_IsValid(0xFDD0, 0xFDEF), false);
+  assert_equal(Uni_IsValid(0xFDF0, 0xFDFF), true);
+  assert_equal(Uni_IsValid(0xFDF0, 0xFFFD), true);
+
+  // negative range test
+  assert_equal(Uni_IsValid(0, 0x10FFFF), false);         // ends with nonchar
+  assert_equal(Uni_IsValid(0, 0x10FFFD), false);         // contains lots o' nonchars
+  assert_equal(Uni_IsValid(0x20, 0x10), false);          // swapped
+  assert_equal(Uni_IsValid(0xFDEF, 0xFDF0), false);      // just outside range
+  assert_equal(Uni_IsValid(0x0000, 0x010000), false);    // crosses noncharacter plane boundary and other stuff
+  assert_equal(Uni_IsValid(0x010000, 0x020000), false);  // crosses noncharacter plane boundary
+  assert_equal(Uni_IsValid(0x0000, 0xFFFF), false);      // crosses other BMP prohibited and plane boundary
+  assert_equal(Uni_IsValid(0x0000, 0xFFFD), false);      // crosses other BMP prohibited
+  assert_equal(Uni_IsValid(0x0000, 0xE000), false);      // crosses surrogate space
+  assert_equal(Uni_IsValid(0x0000, 0x20FFFF), false);      // out of bounds
+  assert_equal(Uni_IsValid(0x10FFFD, 0x20FFFF), false);      // out of bounds
+
+ }
+
 constexpr const auto help_str = u"\
 test_kmx_xstring [--color]\n\
 \n\
@@ -1256,6 +1428,9 @@ int main(int argc, char *argv []) {
   test_decxstr();
   test_xstrlen();
   test_xstrlen_ignoreifopt();
+  test_utf32();
+  test_u16string_to_u32string();
+  test_is_valid();
 
   return 0;
 }
