@@ -3,12 +3,14 @@
 import datetime
 import logging
 import os
+import tempfile
 import time
 
 import requests
 import requests_cache
 from gi.repository import GObject
 
+from keyman_config import _
 from keyman_config import KeymanApiUrl, KeymanDownloadsUrl
 from keyman_config.deprecated_decorator import deprecated
 
@@ -20,6 +22,16 @@ class InstallLocation(GObject.GEnum):
     Unknown = 99
 
 
+def get_install_area_string(area):
+    if area == InstallLocation.OS:
+        return _('System')
+    elif area == InstallLocation.Shared:
+        return _('Shared')
+    elif area == InstallLocation.User:
+        return _('User')
+    return _('Unknown')
+
+
 def get_package_download_data(packageID, weekCache=False):
     """
     Get package download data from keyboards download api.
@@ -74,7 +86,10 @@ def get_keyboard_data(keyboardID, weekCache=False):
     os.chdir(cache_dir)
     requests_cache.install_cache(cache_name='keyman_cache', backend='sqlite', expire_after=expire_after)
     now = time.ctime(int(time.time()))
-    response = requests.get(api_url)
+    try:
+        response = requests.get(api_url)
+    except requests.exceptions.RequestException as e:  # This is the correct syntax
+        return None
     logging.debug('Time: {0} / Used Cache: {1}'.format(now, response.from_cache))
     os.chdir(current_dir)
     requests_cache.uninstall_cache()
@@ -106,7 +121,11 @@ def keyman_cache_dir():
     cachebase = os.environ.get('XDG_CACHE_HOME', os.path.join(home, '.cache'))
     km_cache = os.path.join(cachebase, 'keyman')
     if not os.path.isdir(km_cache):
-        os.mkdir(km_cache)
+        try:
+            os.makedirs(km_cache)
+        except:
+            km_cache = tempfile.TemporaryDirectory().name
+            os.makedirs(km_cache)
     return km_cache
 
 
